@@ -2,15 +2,20 @@ Menu.importrdacsv <- function(){
 ## Aktualisierung des neuen Namens bei nderung in designsel funktioniert noch nicht
 ## tkbind event vermutlich nicht gut gewhlt!
 
-putRcmdr("nameVar", tclVar(""))
-putRcmdr("newnameVar", tclVar(""))
-putRcmdr("designs", listDesigns())
+if (!exists("nameVar")) putRcmdr("nameVar", tclVar(""))
+if (!exists("newnameVar")) putRcmdr("newnameVar", tclVar(""))
+if (!exists("loadVar")) putRcmdr("designs", character(0))
+   else {
+   if (tclvalue(loadVar)=="") putRcmdr("designs", character(0)) 
+   else putRcmdr("designs", listDesigns())
+   }
 
 onOK <- function(){
      closeDialog(window=topdes2)
   ### capture error messages from export function
         name <- tclvalue(nameVar)
         newname <- tclvalue(newnameVar)
+        putRcmdr("decimal.setting", tclvalue(decimalrbVariable))
         if (is.element(newname, listObjects()))
           {
           if ("no" == tclvalue(checkReplace(newname, gettextRcmdr("Object"))))
@@ -52,6 +57,10 @@ onOK <- function(){
         assign(newname, hilf, envir=.GlobalEnv)
         logger(paste(newname, "<-", command))
         activeDataSet(newname)
+        putRcmdr("fileVar", tclVar(""))
+        putRcmdr("loadVar", tclVar(""))
+        putRcmdr("nameVar", tclVar(""))
+        putRcmdr("newnameVar", tclVar(""))
         closeDialog(window=topdes2)
         tkwm.deiconify(CommanderWindow())
         tkfocus(CommanderWindow())
@@ -67,6 +76,15 @@ dquote <- function(obj){
     aus
 }
 
+ onChangeDir <- function(){
+     putRcmdr("direct",tclvalue(tkchooseDirectory()))
+     if (!direct=="") {
+        putRcmdr("dirVar", tclVar(direct))
+        tkconfigure(dirEntry, textvariable = dirVar)
+        setwd(direct)
+        }
+ }
+
  onChangerdaFile <- function(){
      fn <- tclvalue(tkgetOpenFile(filetypes=
         gettextRcmdr('{"R Data Files" {".rda" ".Rda" ".RDA" ".RData"}} {"All Files" {"*"}}')))
@@ -91,8 +109,8 @@ dquote <- function(obj){
         }
  }
      namechange <- function(){
-        if (tclvalue(newnameVar)==".withresp" & !tclvalue(nameVar)=="")
-        putRcmdr("newnameVar", paste(tclvalue(nameVar),".withresp",sep="."))
+        if (tclvalue(newnameVar)=="" & !tclvalue(nameVar)=="")
+        putRcmdr("newnameVar", paste(tclvalue(nameVar),"withresp",sep="."))
         tkconfigure(newnameEntry, textvariable=newnameVar)
     }
  ######## end define functions                          
@@ -100,10 +118,18 @@ dquote <- function(obj){
 ##### define userform
 initializeDialogDoE(title=gettextRcmdr("Import design from rda and csv ..."))   
 
+dirFrame <- ttklabelframe(topdes2, text=gettextRcmdr("Directory"))
+putRcmdr("dirVar", tclVar(getwd()))
+dirEntry <- tkentry(dirFrame, width="50", textvariable=dirVar)
+dirButton <- buttonRcmdr(dirFrame, text = gettextRcmdr("Change \n working directory"), 
+        foreground = "darkgreen", width = "20", command=onChangeDir, 
+        default = "normal", borderwidth = 3)
+tkgrid(dirEntry, tklabel(dirFrame, text="   "), dirButton, sticky="w")
+tkgrid(dirFrame)
 
 ## import file names for rda and csv
 loadFrame <- ttklabelframe(topdes2, text=gettextRcmdr("rda file with design"))
-putRcmdr("loadVar", tclVar(""))
+if (!exists("loadVar")) putRcmdr("loadVar", tclVar(""))
 loadEntry <- tkentry(loadFrame, width="50", textvariable=loadVar)
 loadButton <- buttonRcmdr(loadFrame, text = gettextRcmdr("Select rda file"), 
         foreground = "darkgreen", width = "20", command = onChangerdaFile, 
@@ -112,7 +138,7 @@ tkgrid(loadEntry, tklabel(loadFrame, text="   "), loadButton, sticky="w")
 
 
 fileFrame <- ttklabelframe(topdes2, text=gettextRcmdr("csv file with response data"))
-putRcmdr("fileVar", tclVar(""))
+if (!exists("fileVar")) putRcmdr("fileVar", tclVar(""))
 fileEntry <- tkentry(fileFrame, width="50", textvariable=fileVar)
 fileButton <- buttonRcmdr(fileFrame, text = gettextRcmdr("Select csv file"), 
         foreground = "darkgreen", width = "20", command = onChangecsvFile, 
@@ -120,6 +146,7 @@ fileButton <- buttonRcmdr(fileFrame, text = gettextRcmdr("Select csv file"),
       ## radio buttons for choosing import decimal separator
 decimalradioFrame <- ttklabelframe(fileFrame, text=gettextRcmdr("Decimal Separator ?"))
 decimalrbVariable <- tclVar("default")
+if (exists("decimal.setting")) decimalrbVariable <- tclVar(decimal.setting)
 defaultrb <- tkradiobutton(decimalradioFrame,text=gettextRcmdr("default"),variable=decimalrbVariable, value="default")
 pointrb <- tkradiobutton(decimalradioFrame,text=gettextRcmdr("."),variable=decimalrbVariable, value=".")
 commarb <- tkradiobutton(decimalradioFrame,text=gettextRcmdr(","),variable=decimalrbVariable, value=",")
@@ -136,7 +163,7 @@ designFrame <- tkframe(topdes2)
 designsel <- ttkcombobox(designFrame, textvariable=nameVar, values=designs, state="readonly")
 if (length(designs)==1) tcl(designsel, "current", 0)
 .activeDataSet <- ActiveDataSet()
-    tkbind(designsel, "<FocusOut>", namechange)
+    tkbind(designsel, "<<ComboboxSelected>>", namechange)
 
 replacecbVariable <- tclVar("0")
 replacecb <- ttkcheckbutton(designFrame,text=gettextRcmdr("Replace responses, \nif they exist already"),
@@ -147,7 +174,8 @@ if (.activeDataSet %in% designs) tcl(designsel, "current", which(designs==.activ
 tkgrid(designsel, replacecb, sticky="w")
 
 newnamelabel <- tklabel(topdes2, text="Name for new design")
-putRcmdr("newnameVar", tclVar(paste(tclvalue(nameVar),"withresp",sep=".")))
+if (tclvalue(newnameVar)=="" & !tclvalue(nameVar)=="") 
+     putRcmdr("newnameVar", tclVar(paste(tclvalue(nameVar),"withresp",sep=".")))
 newnameEntry <- tkentry(topdes2, width="50", textvariable=newnameVar)
 
 
